#[repr(C)]pub struct VhtOperation {
pub bytes: [u8; 5],
}Expand description
The wire type corresponding to VhtOperation.
Fields
bytes: [u8; 5]Trait Implementations
Sourceimpl Clone for VhtOperation
impl Clone for VhtOperation
Sourcefn clone(&self) -> VhtOperation
fn clone(&self) -> VhtOperation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for VhtOperation
impl Constrained for VhtOperation
Sourceimpl Debug for VhtOperation
impl Debug for VhtOperation
Sourceimpl<___D> Decode<___D> for VhtOperationwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for VhtOperationwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<VhtOperation, ___E> for &'a VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<VhtOperation, ___E> for &'a VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VhtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VhtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<VhtOperation, ___E> for VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<VhtOperation, ___E> for VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, VhtOperation>
const COPY_OPTIMIZATION: CopyOptimization<Self, VhtOperation>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VhtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VhtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<VhtOperation, ___E> for VhtOperation<T0>
impl<___E, T0> Encode<VhtOperation, ___E> for VhtOperation<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VhtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VhtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<VhtOperation> for VhtOperation
impl FromWire<VhtOperation> for VhtOperation
Sourceconst COPY_OPTIMIZATION: CopyOptimization<VhtOperation, Self>
const COPY_OPTIMIZATION: CopyOptimization<VhtOperation, Self>
Sourcefn from_wire(wire: VhtOperation) -> Self
fn from_wire(wire: VhtOperation) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<VhtOperation> for VhtOperation
impl FromWireRef<VhtOperation> for VhtOperation
Sourcefn from_wire_ref(wire: &VhtOperation) -> Self
fn from_wire_ref(wire: &VhtOperation) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for VhtOperation
impl IntoNatural for VhtOperation
Sourcetype Natural = VhtOperation
type Natural = VhtOperation
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for VhtOperation
impl Wire for VhtOperation
Sourcetype Narrowed<'de> = VhtOperation
type Narrowed<'de> = VhtOperation
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.