#[repr(C)]pub struct WlanChannel {
pub primary: u8,
pub cbw: ChannelBandwidth,
pub secondary80: u8,
}Expand description
The wire type corresponding to WlanChannel.
Fields
primary: u8cbw: ChannelBandwidthsecondary80: u8Trait Implementations
Sourceimpl Clone for WlanChannel
impl Clone for WlanChannel
Sourcefn clone(&self) -> WlanChannel
fn clone(&self) -> WlanChannel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for WlanChannel
impl Constrained for WlanChannel
Sourceimpl Debug for WlanChannel
impl Debug for WlanChannel
Sourceimpl<___D> Decode<___D> for WlanChannelwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for WlanChannelwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<WlanChannel, ___E> for &'a WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanChannel, ___E> for &'a WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanChannel>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanChannel>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<WlanChannel, ___E> for WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanChannel, ___E> for WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanChannel>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanChannel>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<WlanChannel, ___E> for WlanChannel<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<u8, ___E>,
T1: Encode<ChannelBandwidth, ___E>,
T2: Encode<u8, ___E>,
impl<___E, T0, T1, T2> Encode<WlanChannel, ___E> for WlanChannel<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<u8, ___E>,
T1: Encode<ChannelBandwidth, ___E>,
T2: Encode<u8, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanChannel>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanChannel>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WlanChannel> for WlanChannel
impl FromWire<WlanChannel> for WlanChannel
Sourcefn from_wire(wire: WlanChannel) -> Self
fn from_wire(wire: WlanChannel) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<WlanChannel> for WlanChannel
impl FromWireRef<WlanChannel> for WlanChannel
Sourcefn from_wire_ref(wire: &WlanChannel) -> Self
fn from_wire_ref(wire: &WlanChannel) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for WlanChannel
impl IntoNatural for WlanChannel
Sourcetype Natural = WlanChannel
type Natural = WlanChannel
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WlanChannel
impl Wire for WlanChannel
Sourcetype Narrowed<'de> = WlanChannel
type Narrowed<'de> = WlanChannel
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.